/*
 * OI.h
 *
 *  Created on: Oct 16, 2017
 *      Author: jonah
 */

#ifndef SRC_DRIVERINPUTS_OI_H_
#define SRC_DRIVERINPUTS_OI_H_

#include <driverInputs/OIInterfaces/IOIDriver.h>
#include <driverInputs/OIInterfaces/IOICopilot.h>
#include <utils/DragonMath.h>

/*
 * OI is NOT an interface. I kept getting it confused lel.
 *
 * OI provides all robot actions that are controlled by the drivers and copilots
 * e.g. GetRobotXMagnitude() would return the driver's X magnitude on their controller.
 * GetShoot() would return if the shoot button is pressed on the copilot's controller.
 */

namespace Team302 {

class OI {
public:
	enum ControllerType {
		CONTROLLER,
		JOYSTICK
	};

	static OI* GetInstance();
	void ChangeControllerConfig(ControllerType driverControllerType, ControllerType copilotControllerType);
	double GetRobotXMagnitude();
	double GetRobotYMagnitude();
	double GetRobotRotationMagnitude();
	Vector2 GetRobotTargetHeading();


private:
	//Constructor takes in the controller types for the driver and copilot
	OI(ControllerType driverControllerType, ControllerType copilotControllerType);
	//Default constructor
	OI();
	virtual ~OI();

	static OI* m_instance;

	IOIDriver* m_driver;
	IOICopilot* m_copilot;

	ControllerType m_driverControllerType;
	ControllerType m_copilotControllerType;
};

} /* namespace Team302 */

#endif /* SRC_DRIVERINPUTS_OI_H_ */
