/*
 * IOIDriver.h
 *
 *  Created on: Oct 16, 2017
 *      Author: jonah
 */

#ifndef SRC_DRIVERINPUTS_IOIDRIVER_H_
#define SRC_DRIVERINPUTS_IOIDRIVER_H_

#include <utils/DragonMath.h>

namespace Team302 {

/*
* IOIDriver is a sub-oi for one of the two drivers.
 * It only handles actions that the driver is responsible for
 * OI contains one IOIDriver and one IOICopilot and maps its methods to the right driver.
 * e.g. OI might contain GetRobotXMagnitude and GetShoot. OI's method for GetRobotXMagnitude
* would call the IOIDriver's GetRobotXMagnitude and OI's method for GetShoot would call the
 * IOICopilot's GetShoot method.
 */

class IOIDriver {
public:
	IOIDriver() = default;
	virtual ~IOIDriver() = default;

	virtual double GetRobotXMagnitude() const = 0;
	virtual double GetRobotYMagnitude() const = 0;
	virtual double GetRobotRotationMagnitude() const = 0;
	virtual Vector2 GetRobotTargetHeading() const = 0;
};

} /* namespace Team302 */

#endif /* SRC_DRIVERINPUTS_IOIDRIVER_H_ */
