/*
 * IChassis.h
 *
 *  Created on: Oct 5, 2017
 *      Author: jonah
 */

#ifndef SRC_SUBSYS_INTERFACES_ICHASSIS_H_
#define SRC_SUBSYS_INTERFACES_ICHASSIS_H_

namespace Team302 {

class IChassis {
public:

	enum ChassisType {
		MECANUM,
		REGULAR
	};

	enum TargetLocationMode { //TODO: might remove this
		GLOBAL,  // (0, 0) is some location on the field (for field drive use)
		RELATIVE // (0, 0) is robot center
	};

	enum MovementMode {
		POWER,
		LOCATION
	};

	virtual double GetVelocity() const = 0; //in inches per second
	virtual double GetXLocation() const = 0;
	virtual double GetYLocation() const = 0;
	virtual double GetHeading() const = 0; //In degrees, + is clockwise
	//Returns what chassis type this is.
	virtual ChassisType GetChassisType() const = 0;
	//Methods for location drive mode
	virtual void SetTargetLocation(double newTargetX, double newTargetY) = 0;
	virtual void SetPathTravelVelocity(double newTravelVelocity) = 0; //in inches per second
	virtual void SetTargetLocationMode(TargetLocationMode newTargetLocationMode) = 0;

	//Methods for power drive mode
	virtual void SetPowerMagnitudes(double xPower, double yPower, double rotationPower) = 0; // from -1 to 1. used in teleop drive
	virtual void SetLeftRightPower(double leftPower, double rightPower) = 0;
	virtual void UpdateChassis() = 0; //This applies all motor speeds/power/velocity to the cantalons and updates the x, y direction calculations

	virtual void PrintDebug() = 0; // SmartDashboard stuff

	//TODO: add getters for max velocity (strafe velocity will be different) to be used in automatic controller calibration

	IChassis() = default;
	virtual ~IChassis() = default;
};

} /* namespace Team302 */

#endif /* SRC_SUBSYS_INTERFACES_ICHASSIS_H_ */
